@@ -3,7 +3,7 @@
  *
  * This program is licensed under BSD license, read COPYING
  *
- *  $Id: conky.h,v 1.10 2005/08/30 14:59:37 winkj Exp $
+ *  $Id: conky.h,v 1.13 2005/10/16 11:53:36 mirrorbox Exp $
  */
 
 #ifndef _conky_h_
@@ -19,6 +19,11 @@
 #include <locale.h>
 #include <langinfo.h>
 #include <wchar.h>
+#if defined(__FreeBSD__)
+#include <sys/param.h>
+#include <sys/mount.h>
+#include <sys/ucred.h>
+#endif /* __FreeBSD__ */
 
 #ifdef X11
 #if defined(HAVE_CAIRO_H) && defined(HAVE_CAIRO_XLIB_H) && defined(WANT_CAIRO)
@@ -30,7 +35,7 @@
 #endif
 #endif /* X11 */
 
-#if defined(__FreeBSD__)
+#if defined(__FreeBSD__) && (defined(i386) || defined(__i386__))
 #include <machine/apm_bios.h>
 #endif /* __FreeBSD__ */
 
@@ -96,6 +101,9 @@ struct mpd_s {
 	char *artist;
 	char *album;
 	char *status;
+	char *random;
+	char *repeat;
+	char *track;
 	int volume;
 	unsigned int port;
 	char host[128];
@@ -360,7 +368,7 @@ void update_seti();
 #endif
 
 /* in freebsd.c */
-#ifdef __FreeBSD__
+#if defined(__FreeBSD__) && (defined(i386) || defined(__i386__))
 int apm_getinfo(int fd, apm_info_t aip);
 char *get_apm_adapter(void);
 char *get_apm_battery_life(void);
