@@ -1,7 +1,7 @@
 /* linux.c
  * Contains linux specific code
  *
- *  $Id: linux.c,v 1.22 2005/09/05 02:09:31 brenden1 Exp $
+ *  $Id: linux.c,v 1.26 2005/10/15 16:20:25 winkj Exp $
  */
 
 
@@ -307,7 +307,8 @@ inline void update_wifi_stats()
 
 		sscanf(p, "%*d   %d.  %d.  %d", &l, &m, &n);
 
-		ns->linkstatus = (int) (log(l) / log(92) * 100);
+		ns->linkstatus = (int) (log(MIN(MAX(l,1),92)) / log(92) * 100);
+
 	}
 
 	/*** end wireless patch ***/
@@ -562,7 +563,7 @@ open_i2c_sensor(const char *dev, const char *type, int n, int *div,
 		char *devtype)
 {
 	char path[256];
-	char buf[64];
+	char buf[256];
 	int fd;
 	int divfd;
 
@@ -1243,3 +1244,4 @@ void update_diskio()
 
 	diskio_value = tot;
 }
+
